@@ -61,8 +61,6 @@ struct _GtkhtmlColorComboPrivate {
 
 	guint popup_shown	: 1;
 	guint popup_in_progress	: 1;
-	GdkDevice *grab_keyboard;
-	GdkDevice *grab_mouse;
 };
 
 static gpointer parent_class;
@@ -120,8 +118,6 @@ static struct {
 	{ "#FFFFFF", N_("white") }
 };
 
-static void color_combo_build_popup_window (GtkhtmlColorCombo *combo);
-
 static void
 color_combo_notify_current_color_cb (GtkhtmlColorCombo *combo)
 {
@@ -576,7 +572,7 @@ color_combo_dispose (GObject *object)
 	}
 
 	if (priv->window != NULL) {
-		gtk_widget_destroy (priv->window);
+		g_object_unref (priv->window);
 		priv->window = NULL;
 	}
 
@@ -641,32 +637,15 @@ color_combo_popup (GtkhtmlColorCombo *combo)
 	GtkToggleButton *toggle_button;
 	GtkButton *button;
 	GdkWindow *window;
-	gboolean grab_status;
-	GdkDevice *device, *mouse, *keyboard;
-	guint32 activate_time;
+	GdkGrabStatus status;
 	const gchar *label;
 
-	device = gtk_get_current_event_device ();
-	g_return_if_fail (device != NULL);
-
 	if (!gtk_widget_get_realized (GTK_WIDGET (combo)))
 		return;
 
 	if (combo->priv->popup_shown)
 		return;
 
-	if (!combo->priv->window)
-		color_combo_build_popup_window (combo);
-
-	activate_time = gtk_get_current_event_time ();
-	if (gdk_device_get_source (device) == GDK_SOURCE_KEYBOARD) {
-		keyboard = device;
-		mouse = gdk_device_get_associated_device (device);
-	} else {
-		keyboard = gdk_device_get_associated_device (device);
-		mouse = device;
-	}
-
 	/* Update the default button label. */
 	button = GTK_BUTTON (combo->priv->default_button);
 	label = gtkhtml_color_state_get_default_label (combo->priv->state);
@@ -685,28 +664,22 @@ color_combo_popup (GtkhtmlColorCombo *combo)
 
 	/* Try to grab the pointer and keyboard. */
 	window = gtk_widget_get_window (combo->priv->window);
-	grab_status = !keyboard ||
-		gdk_device_grab (keyboard, window,
-			GDK_OWNERSHIP_WINDOW, TRUE,
-			GDK_KEY_PRESS_MASK | GDK_KEY_RELEASE_MASK,
-			NULL, activate_time) == GDK_GRAB_SUCCESS;
-	if (grab_status) {
-		grab_status = !mouse ||
-			gdk_device_grab (mouse, window,
-				GDK_OWNERSHIP_WINDOW, TRUE,
-				GDK_BUTTON_PRESS_MASK | GDK_BUTTON_RELEASE_MASK | GDK_POINTER_MOTION_MASK,
-				NULL, activate_time) == GDK_GRAB_SUCCESS;
-		if (!grab_status && keyboard)
-			gdk_device_ungrab (keyboard, activate_time);
+	status = gdk_pointer_grab (
+		window, TRUE,
+		GDK_BUTTON_PRESS_MASK | GDK_BUTTON_RELEASE_MASK |
+		GDK_POINTER_MOTION_MASK, NULL, NULL, GDK_CURRENT_TIME);
+	if (status == GDK_GRAB_SUCCESS) {
+		status = gdk_keyboard_grab (window, TRUE, GDK_CURRENT_TIME);
+		if (status != GDK_GRAB_SUCCESS)
+			gdk_display_pointer_ungrab (
+				gdk_window_get_display (window),
+				GDK_CURRENT_TIME);
 	}
 
-	if (grab_status) {
-		gtk_device_grab_add (combo->priv->window, mouse, TRUE);
-		combo->priv->grab_keyboard = keyboard;
-		combo->priv->grab_mouse = mouse;
-	} else {
+	if (status == GDK_GRAB_SUCCESS)
+		gtk_grab_add (combo->priv->window);
+	else
 		gtk_widget_hide (combo->priv->window);
-	}
 }
 
 static void
@@ -721,20 +694,12 @@ color_combo_popdown (GtkhtmlColorCombo *combo)
 		return;
 
 	/* Hide the pop-up. */
-	gtk_device_grab_remove (combo->priv->window, combo->priv->grab_mouse);
+	gtk_grab_remove (combo->priv->window);
 	gtk_widget_hide (combo->priv->window);
 
 	/* Deactivate the toggle button. */
 	toggle_button = GTK_TOGGLE_BUTTON (combo->priv->toggle_button);
 	gtk_toggle_button_set_active (toggle_button, FALSE);
-
-	if (combo->priv->grab_keyboard)
-		gdk_device_ungrab (combo->priv->grab_keyboard, GDK_CURRENT_TIME);
-	if (combo->priv->grab_mouse)
-		gdk_device_ungrab (combo->priv->grab_mouse, GDK_CURRENT_TIME);
-
-	combo->priv->grab_keyboard = NULL;
-	combo->priv->grab_mouse = NULL;
 }
 
 static void
@@ -880,8 +845,11 @@ static void
 color_combo_init (GtkhtmlColorCombo *combo)
 {
 	GtkhtmlColorState *state;
+	GtkWidget *toplevel;
 	GtkWidget *container;
 	GtkWidget *widget;
+	GtkWidget *window;
+	guint ii;
 
 	combo->priv = G_TYPE_INSTANCE_GET_PRIVATE (
 		combo, GTKHTML_TYPE_COLOR_COMBO, GtkhtmlColorComboPrivate);
@@ -927,33 +895,22 @@ color_combo_init (GtkhtmlColorCombo *combo)
 	g_signal_connect_swapped (
 		combo->priv->toggle_button, "toggled",
 		G_CALLBACK (color_combo_toggled_cb), combo);
-}
 
-static void
-color_combo_build_popup_window (GtkhtmlColorCombo *combo)
-{
-	GtkWidget *toplevel;
-	GtkWidget *container;
-	GtkWidget *widget;
-	GtkWidget *window;
-	guint ii;
-
-	g_return_if_fail (combo->priv->window == NULL);
+	/* Build the pop-up window. */
 
 	window = gtk_window_new (GTK_WINDOW_POPUP);
 	toplevel = gtk_widget_get_toplevel (GTK_WIDGET (combo));
 	gtk_window_set_resizable (GTK_WINDOW (window), FALSE);
 	gtk_window_set_type_hint (
 		GTK_WINDOW (window), GDK_WINDOW_TYPE_HINT_COMBO);
-	if (GTK_IS_WINDOW (toplevel)) {
+	if (gtk_widget_is_toplevel (toplevel)) {
 		gtk_window_group_add_window (
 			gtk_window_get_group (GTK_WINDOW (toplevel)),
 			GTK_WINDOW (window));
 		gtk_window_set_transient_for (
 			GTK_WINDOW (window), GTK_WINDOW (toplevel));
 	}
-
-	combo->priv->window = window;
+	combo->priv->window = g_object_ref (window);
 
 	g_signal_connect_swapped (
 		window, "show",
